@@ -9,43 +9,49 @@ knitr::opts_chunk$set(
 library(ichimoku)
 
 ## ----loaddatanotrun, eval = FALSE---------------------------------------------
-#  # ichimoku is designed to interface well with other packages, for example the following works:
+#  # ichimoku is designed to interface well with other packages, for example:
 #  cloud <- ichimoku(quantmod::getSymbols("C"))
 
 ## ----viewdata-----------------------------------------------------------------
-# Synthetic OHLC pricing data is assigned to data frame 'TKR':
+# Simulated OHLC price data is assigned to data frame 'TKR':
 TKR <- sample_ohlc_data
 head(TKR)
 
 ## ----ichimoku-----------------------------------------------------------------
 cloud <- ichimoku(TKR)
 
-print(cloud[100:110,], plot = FALSE, row.names = FALSE, digits = 4)
+print(cloud[100:110,], plot = FALSE, digits = 4)
 
 ## ----ichimokunotrun, eval = FALSE---------------------------------------------
 #  # to view data as well as chart, simply issue:
 #  cloud
 
+## ----holidays, eval = FALSE---------------------------------------------------
+#  # Holidays can be specified directly via a vector of dates:
+#  ichimoku(TKR, holidays = c("2021-12-25", "2022-01-01"))
+#  
+#  # Or via a functions that returns a vector of dates (e.g. from the 'timeDate' package):
+#  ichimoku(TKR, holidays = timeDate::holidayLONDON())
+#  ichimoku(TKR, holidays = timeDate::holidayNYSE())
+
 ## ----plot---------------------------------------------------------------------
 plot(cloud)
 
 ## ----plotnotrun, eval = FALSE-------------------------------------------------
-#  # The following would work if you wanted to add/replace ggplot2 layers:
+#  # Example code for incrementally updating ggplot2 layers:
 #  plot <- plot(cloud)
 #  plot + ggplot2::theme_classic()
 
 ## ----iplotnotrun, eval = FALSE------------------------------------------------
-#  # For interactive charting, take your pick of:
+#  # For interactive charting:
 #  iplot(cloud)
-#  # which is equivalent to:
-#  plot(cloud, i = TRUE)
-#  # which is also equivalent to, using argument position matching and abbreviation of TRUE:
-#  plot(cloud, T)
 
 ## ----plot2--------------------------------------------------------------------
-plot(cloud, from = "2020-05-01", to = "2020-11-01", ticker = "TKR Co.", theme = "dark", gaps = TRUE)
+plot(cloud, window = "2020-05-01/2020-11-01", ticker = "TKR Co.", theme = "dark", gaps = TRUE)
 
 ## ----pipe, eval = FALSE-------------------------------------------------------
-#  # The following works:
+#  # Using R 4.1's new pipe operator:
+#  quantmod::getSymbols("C") |> ichimoku() |> plot()
+#  # Or equally using the 'magrittr' pipe:
 #  quantmod::getSymbols("C") %>% ichimoku() %>% plot()
 
